@@ -16,6 +16,7 @@
 # Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 """Recipe fss"""
 import os
+from warnings import warn
 
 class Recipe(object):
     """This recipe is used by zc.buildout"""
@@ -26,17 +27,35 @@ class Recipe(object):
         # XXX this is a bit hacky, see how we can get the var folder in a cleany
         # way
         self.var = os.path.join(os.path.split(bin_dir)[0], 'var')
+        self.conf_paths = []
 
         if 'conf' in options:
-            self.etc = options['conf']
-        else:
-            if 'instance' in buildout:
-                z2_location = buildout['instance']['location']
-            else:
-                z2_location = buildout['zopeinstance']['location']
+            self.conf_paths.append(options['conf'])
+            warn("Use 'zope-instances' parameters instead of 'conf'",
+                 DeprecationWarning, stacklevel=2)
 
-            self.etc = os.path.join(z2_location, 'etc',
-                                'plone-filesystemstorage.conf')
+        elif 'zope-instances' in options:
+            for dir_path in options['zope-instances'].strip().split('\n'):
+                if os.path.exists(dir_path.strip()):
+                    self.conf_paths.append(os.path.join(dir_path.strip(), 'etc',
+                                                        'plone-filesystemstorage.conf'))
+                else:
+                    raise IOError("'%s' doesn't exist" % dir_path.strip())
+
+        else:
+            # Nor 'conf' neither 'zope-instances' parameters are defined.
+            # We try to find classic zope instance names in the local
+            # configuration file.
+            if 'instance' in buildout:
+                instance_location = buildout['instance']['location']
+            elif 'zopeinstance' in buildout:
+                instance_location = buildout['zopeinstance']['location']
+            else:
+                raise KeyError("The system is unable to find a Zope instance. "
+                               "Please use the zope-instance parameter.")
+
+            self.conf_paths.append(os.path.join(instance_location, 'etc',
+                                                'plone-filesystemstorage.conf'))
         # reading the storages
 
         def _read_storage_line(line):
@@ -104,17 +123,22 @@ class Recipe(object):
                                        'strategy': strategy,
                                        'storage': storage,
                                        'backup': backup})
-        # write the conf file
-        etc = open(self.etc, 'w')
-        try:
-            etc.write('# FSS conf file generated by iw.recipe.fss\n\n')
-            for conf in conf_content:
-                etc.write(conf)
-        finally:
-            etc.close()
 
-        # returns installed files
-        return (self.etc, ) 
+        if len(self.conf_paths) > 0:
+            for conf_path in self.conf_paths:
+
+                etc = open(conf_path, 'w')
+                try:
+                    etc.write('# FSS conf file generated by iw.recipe.fss\n\n')
+                    for conf in conf_content:
+                        etc.write(conf)
+                finally:
+                    etc.close()
+
+            # returns installed files
+            return tuple(self.conf_paths)
+
+        else:
+            raise KeyError('No filesystem path found in configuration')
 
     update = install
-
